@@ -48,9 +48,7 @@ typedef enum
     TERMINAL_WINDOW_ACTION_CLOSE_WINDOW,
     TERMINAL_WINDOW_ACTION_EDIT_MENU,
     TERMINAL_WINDOW_ACTION_COPY,
-#if VTE_CHECK_VERSION (0, 49, 2)
     TERMINAL_WINDOW_ACTION_COPY_HTML,
-#endif
     TERMINAL_WINDOW_ACTION_PASTE,
     TERMINAL_WINDOW_ACTION_PASTE_ALT,
     TERMINAL_WINDOW_ACTION_PASTE_SELECTION,
@@ -94,6 +92,17 @@ typedef enum
     TERMINAL_WINDOW_ACTION_READ_ONLY,
     TERMINAL_WINDOW_ACTION_SCROLL_ON_OUTPUT,
 
+    /* go-to tab accelerators */
+    TERMINAL_WINDOW_ACTION_GOTO_TAB_1,
+    TERMINAL_WINDOW_ACTION_GOTO_TAB_2,
+    TERMINAL_WINDOW_ACTION_GOTO_TAB_3,
+    TERMINAL_WINDOW_ACTION_GOTO_TAB_4,
+    TERMINAL_WINDOW_ACTION_GOTO_TAB_5,
+    TERMINAL_WINDOW_ACTION_GOTO_TAB_6,
+    TERMINAL_WINDOW_ACTION_GOTO_TAB_7,
+    TERMINAL_WINDOW_ACTION_GOTO_TAB_8,
+    TERMINAL_WINDOW_ACTION_GOTO_TAB_9,
+
     TERMINAL_WINDOW_ACTION_N
 } TerminalWindowAction;
 
